@@ -1,7 +1,7 @@
 import numpy as np
 import pandas as pd
-import os
-import datetime
+# import os
+# import datetime
 from iambcodes.rates import *
 
 def GrowthCheck(myDat, myThresh):
@@ -27,7 +27,7 @@ def GrowthPhase(myDat, myThresh=.05):
 ############################
 #
 ############################
-def GP_PlateData(FileName, GrowthThresh=3, GVcorrect={'GVexp':1, 'eexp':0}, GPsource='GP'):
+def GP_PlateData(FileName, GrowthThresh=3, GVcorrect={'GVexp':1, 'eexp':0, 'Background':0}, GPsource='GP'):
     if GPsource == 'GP-de':
         skiprows = 23
         decimal = ','
@@ -43,12 +43,13 @@ def GP_PlateData(FileName, GrowthThresh=3, GVcorrect={'GVexp':1, 'eexp':0}, GPso
         
     GVexp = GVcorrect['GVexp']
     eexp = GVcorrect['eexp']
+    Background = GVcorrect['Background']
 
     df = pd.read_csv(FileName, skiprows=skiprows , decimal=decimal)
     df = df.drop(labels='Input_Image', axis=1)
     df.dropna(axis=1, inplace=True)
     myTime = pd.Series(df['Time (min)'].values/TimeUnit)
-    myGr = df.loc[:, df.columns != 'Time (min)'].apply(lambda x: CorrectedOD(x, GVexp, eexp))
+    myGr = df.loc[:, df.columns != 'Time (min)'].apply(lambda x: CorrectedOD(x, GVexp, eexp, Background))
     # removing measurements without correct growth magnitude
     GrowthSelect = myGr.apply(lambda x: GrowthCheck(x, GrowthThresh), axis=0)
     myGr.drop(myGr[myGr.columns[~GrowthSelect.values]], axis=1, inplace=True)
@@ -182,11 +183,11 @@ def WellFit(time, biomass, bins, law='log', DeathThresh=.05):
 ############################
 #
 ############################
-def CorrectedOD(GV,expo1,expo2):
+def CorrectedOD(GV,expo1,expo2,Background):
     '''
         Correction of the OD
     '''
-    od = (GV ** expo1) * (np.exp(expo2))
+    od = ((GV-Background) ** expo1) * (np.exp(expo2))
     return od
 ############################
 #
